::: spotify.api.API
    options:
      members:
        - get_album
        - get_several_albums
        - get_album_tracks
        - get_users_saved_albums
        - save_albums_for_current_user
        - remove_users_saved_albums
        - check_users_saved_albums
        - get_new_releases
::: spotify.models.SimpleAlbum
::: spotify.models.Album
::: spotify.models.ArtistAlbum
::: spotify.models.SavedAlbum
